"use strict";

exports.API = void 0;

var axios = require("axios");

var _package = require("../package.json");

// @ts-ignore
const API_ENDPOINT = "https://api.namemc.com/";
const groups = ["profile", "server"];
/**
 * Make requests to NameMC API
 * @example
 * Get player friends
 * ```
 * const api = new API();
 *
 * api.profile.friends({
 *     target: '2e9d9da1-97e9-4564-890b-6f056c4e372f'
 * });
 * ```
 */

class API {
  /**
   * @hidden
   */
  constructor() {
    // @ts-ignore
    this.worker = axios.create({
      baseURL: API_ENDPOINT,
      headers: typeof window === "undefined" ? {
        "User-Agent": `NameMCWrapper/${_package.version} (${_package.homepage})`
      } : {}
    });

    for (const group of groups) {
      this[group] = new Proxy(Object.create(null), {
        get: (object, prop) => ({
          target,
          ...params
        }) => this.request({
          group,
          target,
          prop,
          params
        })
      });
    }
  }
  /**
   * @hidden
   */


  get [Symbol.toStringTag]() {
    return this.constructor.name;
  }
  /**
   * @hidden
   */


  request({
    group,
    target,
    prop,
    params
  }) {
    return this.worker.get(`/${group}/${target ? `${target}/` : ""}${prop}`, {
      params
    }).then(({
      data
    }) => data);
  }

}

exports.API = API;