"use strict";

exports.CapeContext = void 0;

var _context = require("./context");

var _utils = require("../utils");

var _interfaces = require("../interfaces");

class CapeContext extends _context.Context {
  /**
   * @hidden
   */
  constructor({
    hash,
    ...options
  }) {
    super(options);
    /**
     * @hidden
     */

    this.endpoint = this.options.getEndpoint();
    this.hash = hash;
  }
  /**
   * Get cape url
   */


  get url() {
    return `${this.endpoint}/texture/${this.hash}.png`;
  }
  /**
   * Get cape type
   */


  get type() {
    return Object.values(_interfaces.CapeHash).includes(this.hash) ? _interfaces.CapeType.MINECRAFT : _interfaces.CapeType.OPTIFINE;
  }
  /**
   * Get cape name
   */


  get name() {
    const cape = new Map(Object.entries(_interfaces.CapeHash).map(entry => entry.reverse())).get(this.hash);

    if (cape) {
      const capeName = new Map(Object.entries(_interfaces.CapeName)).get(cape);
      return capeName;
    }

    return _interfaces.CapeName.OPTIFINE;
  }
  /**
   * Check is Minecraft cape
   */


  get isMinecraft() {
    return this.type === _interfaces.CapeType.MINECRAFT;
  }
  /**
   * Check is Optifine cape
   */


  get isOptifine() {
    return this.type === _interfaces.CapeType.OPTIFINE;
  }
  /**
   * @hidden
   */


  [_utils.kSerializeData]() {
    return (0, _utils.pickProperties)(this, ["hash", "url", "name", "type"]);
  }

}

exports.CapeContext = CapeContext;