import { Context } from "./";
import { kSerializeData } from "../utils";
import { IGetFollowersOptions, IPlayerContext, IPlayerContextOptions } from "../interfaces";
export declare class PlayerContext extends Context<IPlayerContext> implements IPlayerContext {
    /**
     * Profile ID
     */
    readonly id: IPlayerContext["id"];
    /**
     * Player uuid
     */
    readonly uuid: IPlayerContext["uuid"];
    /**
     * Player username
     */
    readonly username: IPlayerContext["username"];
    /**
     * Profile short url
     */
    readonly url: IPlayerContext["url"];
    /**
     * Profile views
     */
    readonly views: IPlayerContext["views"];
    /**
     * Nickname history
     */
    readonly names: IPlayerContext["names"];
    /**
     * Skin history
     */
    readonly skins: IPlayerContext["skins"];
    /**
     * Player capes
     */
    readonly capes: IPlayerContext["capes"];
    /**
     * Player friends
     */
    readonly friends: IPlayerContext["friends"];
    /**
     * Player favorite servers
     */
    readonly servers: IPlayerContext["servers"];
    /**
     * Player followers
     */
    readonly followers: IPlayerContext["followers"];
    /**
     * Player following
     */
    readonly following: IPlayerContext["following"];
    /**
     * Following date, available when receiving player followers/following
     */
    readonly followingDate: IPlayerContext["followingDate"];
    /**
     * Badlion Client statistics
     *
     * @see {@link https://www.badlion.net/forum/thread/309559 | Announce from Badlion Client}
     */
    readonly badlion: IPlayerContext["badlion"];
    /**
     * Payload loaded
     * @hidden
     */
    private extended;
    /**
     * @hidden
     */
    constructor({ data, isSearch, ...options }: IPlayerContextOptions);
    /**
     * Check payload loaded
     */
    get isExtended(): boolean;
    /**
     * Does the player use Badlion Client
     */
    get usesBadlion(): boolean;
    /**
     * Get clean UUID
     */
    get cleanUUID(): string;
    /**
     * Load all profile information
     */
    loadPayload(): Promise<void>;
    /**
     * Get player followers
     */
    getFollowers(options: IGetFollowersOptions): Promise<IPlayerContext["followers"]>;
    /**
     * Get player following
     */
    getFollowing(options: IGetFollowersOptions): Promise<IPlayerContext["followers"]>;
    /**
     * @hidden
     */
    private loadFollowers;
    /**
     * @hidden
     */
    private parseFollowers;
    /**
     * @hidden
     */
    private parseUsernameHistory;
    /**
     * @hidden
     */
    [kSerializeData](): IPlayerContext;
}
