import { Context } from "./context";
import { kSerializeData } from "../utils";
import { IRendersContext, IRendersContextOptions } from "../interfaces";
export declare class RendersContext extends Context<IRendersContext> implements IRendersContext {
    /**
     * Skin hash
     */
    readonly skin: IRendersContextOptions["skin"];
    /**
     * Cape hash
     */
    readonly cape: IRendersContextOptions["cape"];
    /**
     * Skin model
     */
    readonly model: IRendersContextOptions["model"];
    /**
     * Image render width
     */
    readonly width: IRendersContextOptions["width"];
    /**
     * Image render height
     */
    readonly height: IRendersContextOptions["height"];
    /**
     * Image render scale
     */
    readonly scale: IRendersContextOptions["scale"];
    /**
     * Show skin overlay
     */
    readonly overlay: IRendersContextOptions["overlay"];
    /**
     * Model horizontal rotation angle
     */
    readonly theta: IRendersContextOptions["theta"];
    /**
     * Model vertical rotation angle
     */
    readonly phi: IRendersContextOptions["phi"];
    /**
     * Model animation time
     */
    readonly time: IRendersContextOptions["time"];
    /**
     * Model HEX shadow color
     *
     * @see {@link https://www.color-hex.com/ | HEX Color generator}
     */
    readonly shadow_color: IRendersContextOptions["shadow_color"];
    /**
     * Model shadow color
     */
    readonly shadow_radius: IRendersContextOptions["shadow_radius"];
    /**
     * Model horizontal shadow offset
     */
    readonly shadow_x: IRendersContextOptions["shadow_x"];
    /**
     * Model vertical shadow offset
     */
    readonly shadow_y: IRendersContextOptions["shadow_y"];
    /**
     * @hidden
     */
    protected endpoint: string;
    /**
     * @hidden
     */
    constructor({ options, client, payload, api, ...rendersOptions }: IRendersContextOptions);
    /**
     * Get body render model
     */
    get body(): IRendersContext["body"];
    /**
     * Get face render model url
     */
    get face(): IRendersContext["face"];
    [kSerializeData](): IRendersContext;
}
