"use strict";

exports.RendersContext = void 0;

var _context = require("./context");

var _utils = require("../utils");

var _interfaces = require("../interfaces");

class RendersContext extends _context.Context {
  /**
   * @hidden
   */
  constructor({
    options,
    client,
    payload,
    api,
    ...rendersOptions
  }) {
    super({
      options,
      client,
      payload,
      api
    });
    /**
     * Skin hash
     */

    this.skin = _utils.steveSkinHash;
    /**
     * Cape hash
     */

    this.cape = "";
    /**
     * Skin model
     */

    this.model = _interfaces.Model.UNKNOWN;
    /**
     * Image render width
     */

    this.width = 600;
    /**
     * Image render height
     */

    this.height = 300;
    /**
     * Image render scale
     */

    this.scale = 4;
    /**
     * Show skin overlay
     */

    this.overlay = true;
    /**
     * Model horizontal rotation angle
     */

    this.theta = 30;
    /**
     * Model vertical rotation angle
     */

    this.phi = 20;
    /**
     * Model animation time
     */

    this.time = 90;
    /**
     * Model HEX shadow color
     *
     * @see {@link https://www.color-hex.com/ | HEX Color generator}
     */

    this.shadow_color = "000";
    /**
     * Model shadow color
     */

    this.shadow_radius = 0;
    /**
     * Model horizontal shadow offset
     */

    this.shadow_x = 0;
    /**
     * Model vertical shadow offset
     */

    this.shadow_y = 0;
    /**
     * @hidden
     */

    this.endpoint = this.options.getEndpoint({
      subdomain: "render"
    });
    this.payload = { ...this.payload,
      ...rendersOptions
    };
    this.setupPayload();
  }
  /**
   * Get body render model
   */


  get body() {
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    const {
      endpoint,
      options,
      client,
      api,
      payload,
      ...params
    } = this;
    const front = `${endpoint}/skin/3d/body.png?${new URLSearchParams(params)}`;
    return {
      front,
      front_and_back: `${front}&front_and_back=true`
    };
  }
  /**
   * Get face render model url
   */


  get face() {
    const {
      endpoint,
      skin,
      overlay,
      scale
    } = this;
    return `${endpoint}/skin/2d/face.png?skin=${skin}&overlay=${overlay}&scale=${scale}`;
  }

  [_utils.kSerializeData]() {
    return (0, _utils.pickProperties)(this, ["body", "face"]);
  }

}

exports.RendersContext = RendersContext;