import { Context } from "./context";
import { kSerializeData } from "../utils";
import { ISearchContext, ISearchContextOptions } from "../interfaces";
export declare class SearchContext extends Context<ISearchContext> implements ISearchContext {
    /**
     * Search Query
     */
    readonly query: ISearchContext["query"];
    /**
     * Query name info
     */
    readonly name: ISearchContext["name"];
    /**
     * Query players
     */
    readonly players: ISearchContext["players"];
    /**
     * Query servers
     */
    readonly servers: ISearchContext["servers"];
    /**
     * Query skin tag
     */
    readonly skin: ISearchContext["skin"];
    /**
     * @hidden
     */
    constructor({ data, ...options }: ISearchContextOptions);
    /**
     * Check is query name is available
     */
    get isAvailable(): boolean;
    /**
     * Check is query name is available available later
     */
    get isAvailableLater(): boolean;
    /**
     * Check is query name is unavailable
     */
    get isUnavailable(): boolean;
    /**
     * Check is query name is invalid
     */
    get isInvalid(): boolean;
    /**
     * Check query has players
     */
    get hasPlayers(): boolean;
    /**
     * Check query has servers
     */
    get hasServers(): boolean;
    /**
     * Check query has skin tag name
     */
    get hasSkinTag(): boolean;
    /**
     * @hidden
     */
    [kSerializeData](): ISearchContext;
}
