import * as cheerio from "cheerio";
import { Context } from "./context";
import { kSerializeData } from "../utils";
import { ICheckServerLikeOptions, IServerContext, IServerContextOptions } from "../interfaces";
export declare class ServerContext extends Context<IServerContext> implements IServerContext {
    /**
     * Server ip
     */
    readonly ip: IServerContext["ip"];
    /**
     * Server title
     */
    readonly title: IServerContext["title"];
    /**
     * Server icon url
     */
    readonly icon: IServerContext["icon"];
    /**
     * Server motd
     */
    readonly motd: IServerContext["motd"];
    /**
     * Server current players stats
     */
    readonly players: IServerContext["players"];
    /**
     * Server country
     */
    readonly country: IServerContext["country"];
    /**
     * Server rating
     */
    readonly rating: IServerContext["rating"];
    /**
     * Server version
     */
    readonly version: IServerContext["version"];
    /**
     * Server uptime
     */
    readonly uptime: IServerContext["uptime"];
    /**
     * Payload loaded
     * @hidden
     */
    private extended;
    /**
     * @hidden
     */
    constructor({ data, extended, isSearch, ...options }: IServerContextOptions);
    /**
     * Check payload loaded
     */
    get isExtended(): boolean;
    /**
     * Check like status for player
     */
    checkLike(username: ICheckServerLikeOptions["username"]): Promise<boolean>;
    /**
     * Load all server information
     */
    loadPayload(): Promise<void>;
    /**
     * @hidden
     */
    protected parseServerCard(data: cheerio.Element, isPreview: boolean): Omit<IServerContext, "version" | "uptime"> | Omit<IServerContext, "country" | "ip" | "version" | "uptime">;
    /**
     * @hidden
     */
    protected parseServerCountry(data?: cheerio.Element): IServerContext["country"];
    /**
     * @hidden
     */
    protected parseIP(data: cheerio.Element): IServerContext["ip"];
    /**
     * @hidden
     */
    [kSerializeData](): IServerContext;
}
