"use strict";

exports.ServerContext = void 0;

var cheerio = require("cheerio");

var _context = require("./context");

var _WrapperError = require("../WrapperError");

var _utils = require("../utils");

class ServerContext extends _context.Context {
  /**
   * @hidden
   */
  constructor({
    data,
    extended,
    isSearch,
    ...options
  }) {
    super(options);
    /**
     * Server ip
     */

    this.ip = "";
    /**
     * Server title
     */

    this.title = "";
    /**
     * Server icon url
     */

    this.icon = "";
    /**
     * Server motd
     */

    this.motd = {
      clear: "",
      html: ""
    };
    /**
     * Server current players stats
     */

    this.players = {
      online: 0,
      max: 0
    };
    /**
     * Server country
     */

    this.country = null;
    /**
     * Server rating
     */

    this.rating = 0;
    /**
     * Server version
     */

    this.version = null;
    /**
     * Server uptime
     */

    this.uptime = null;
    /**
     * Payload loaded
     * @hidden
     */

    this.extended = false;
    this.setupPayload();

    if (!data) {
      return;
    }

    const $ = cheerio.load(data);

    if (isSearch) {
      this.payload.players = {};
      $("td").get().forEach((element, index) => {
        const $ = cheerio.load(element);
        const image = $("img");
        const row = $("td");
        const title = $("a");

        switch (index) {
          case 0:
            this.payload.icon = image.attr().src;
            break;

          case 1:
            this.payload.country = this.parseServerCountry(image.get(0));
            break;

          case 2:
            this.payload.title = title.text();
            this.payload.ip = this.parseIP(title.get(0));
            break;

          case 3:
            this.payload.motd = {
              clear: row.attr().title,
              html: ""
            };
            break;

          case 4:
            this.payload.players.online = Number(row.text());
            break;

          case 6:
            this.payload.players.max = Number(row.text());
            break;

          case 7:
            this.payload.rating = Number(row.text().slice(1));
            break;
        }
      });
      this.setupPayload();
      return;
    }

    const serverCard = extended ? this.parseServerCard($("div.card.mb-3").filter((index, element) => {
      var _element$attribs, _element$attribs$styl;

      return element === null || element === void 0 ? void 0 : (_element$attribs = element.attribs) === null || _element$attribs === void 0 ? void 0 : (_element$attribs$styl = _element$attribs.style) === null || _element$attribs$styl === void 0 ? void 0 : _element$attribs$styl.includes("#0F0F0F");
    }).get(0), !extended) : this.parseServerCard(data, !extended);

    if (extended) {
      this.extended = extended;
      const [, infoCard] = $("div.row > div.col-12.col-lg-5").children().filter("div.card.mb-3").get().map(element => {
        const $ = cheerio.load(element);
        return $("div.card.mb-3 > div.card-body").children();
      });
      const {
        version = null,
        uptime = null,
        country = null
      } = Object.assign.apply({}, [{}, ...infoCard.map((index, element) => {
        const $ = cheerio.load(element);
        const rowValue = $("div.row > div.text-right");

        if (rowValue.children().length) {
          return {
            country: this.parseServerCountry(rowValue.children("img").get(0))
          };
        }

        const content = rowValue.contents().get(0) // @ts-ignore
        .data;
        const isUptime = content.endsWith("%");
        return {
          [isUptime ? "uptime" : "version"]: content ? isUptime ? parseFloat(content) : content : null
        };
      }).get()]);
      this.payload = {
        version,
        country,
        uptime
      };
      this.setupPayload();
    }

    this.payload = serverCard;
    this.setupPayload();
  }
  /**
   * Check payload loaded
   */


  get isExtended() {
    return this.extended;
  }
  /**
   * Check like status for player
   */


  async checkLike(username) {
    const endpoint = this.options.getEndpoint({
      domain: "api.ashcon.app"
    });
    const uuid = await (0, _utils.getUUID)(endpoint, username);
    return this.api.server.likes({
      target: this.ip,
      profile: uuid
    });
  }
  /**
   * Load all server information
   */


  async loadPayload() {
    if (this.isExtended) {
      return;
    }

    this.payload = await this.client.get(`/server/${this.ip}`).then(({
      data
    }) => new ServerContext({ ...this,
      data,
      extended: true,
      payload: {
        ip: this.ip
      }
    }));
    this.setupPayload();
    this.extended = true;
  }
  /**
   * @hidden
   */


  parseServerCard(data, isPreview) {
    var _bodyMotd$children$, _bodyMotd$children$$a, _bodyMotd$children$$a2, _bodyMotd$children$2;

    const $ = cheerio.load(data);
    const header = $("div.card-header.p-0 > div.row.no-gutters"); // @ts-ignore

    const [{
      data: title
    }] = header.find(`div.col.text-center.text-nowrap.text-ellipsis.mc-bold${isPreview ? ".p-1" : ".p-2.mc-white"}`).get(0).children; // @ts-ignore

    const [{
      data: rating
    }] = header.find(`div.col-auto.mc-gray${isPreview ? ".p-1" : ".p-2"}`).get(1).children;
    const body = $("div.card-body.p-0 > div.row.no-gutters.flex-nowrap.align-items-center");
    const icon = body.find(`div.col-auto${isPreview ? ".p-1" : ".p-2"} > img`).attr().src;
    const bodyMotd = body.find(`div.col.mc-reset${isPreview ? ".p-1" : ".p-2"}`).children();

    if (!((_bodyMotd$children$ = bodyMotd.children()[0]) !== null && _bodyMotd$children$ !== void 0 && (_bodyMotd$children$$a = _bodyMotd$children$.attribs) !== null && _bodyMotd$children$$a !== void 0 && (_bodyMotd$children$$a2 = _bodyMotd$children$$a.class) !== null && _bodyMotd$children$$a2 !== void 0 && _bodyMotd$children$$a2.includes("float-right")) && !((_bodyMotd$children$2 = bodyMotd.children()[0]) !== null && _bodyMotd$children$2 !== void 0 && _bodyMotd$children$2.next)) {
      throw new _WrapperError.WrapperError("SERVER_OFFLINE", title);
    }

    const motdTitle = bodyMotd.attr().title; // @ts-ignore

    let [{
      children: [{
        data: onlinePlayers
      },, {
        data: maxPlayers
      }],
      next: bodyMotdNext
    }, rawMotd] = bodyMotd.children().get();

    if (!bodyMotdNext) {
      bodyMotdNext = {
        data: ""
      };
    } // @ts-ignore


    const {
      data: textMotd
    } = bodyMotdNext;
    const motdHtml = typeof rawMotd === "object" ? // @ts-ignore Invalid lib type
    cheerio.default.html((0, _utils.escapeColorsClasses)(rawMotd.children)) : textMotd;
    const motdClear = isPreview ? motdTitle : typeof rawMotd === "object" ? (0, _utils.escapeHtml)(rawMotd.children) : textMotd;
    const parsedData = {
      title,
      icon,
      motd: {
        clear: motdClear,
        html: motdHtml
      },
      players: {
        online: Number(onlinePlayers),
        max: Number(maxPlayers)
      },
      rating: Number(rating.slice(1))
    };

    if (isPreview) {
      return { ...parsedData,
        ip: this.parseIP(data),
        country: this.parseServerCountry(header.find("div.col-auto.p-1").children("img").get(0))
      };
    }

    return parsedData;
  }
  /**
   * @hidden
   */


  parseServerCountry(data) {
    if (data) {
      const {
        attribs: {
          title: name,
          src: image,
          alt: emoji
        }
      } = data;
      return {
        name,
        image,
        emoji
      };
    }

    return null;
  }
  /**
   * @hidden
   */


  parseIP(data) {
    return data.attribs.href.replace(/\/[^]+\//, "");
  }
  /**
   * @hidden
   */


  [_utils.kSerializeData]() {
    return (0, _utils.pickProperties)(this, ["ip", "title", "icon", "motd", "players", "country", "rating", "version", "uptime"]);
  }

}

exports.ServerContext = ServerContext;