"use strict";

exports.getUUID = getUUID;
exports.escapeColorsClasses = escapeColorsClasses;
exports.escapeHtml = escapeHtml;
exports.parseDuration = parseDuration;
exports.applyPayload = applyPayload;
exports.pickProperties = pickProperties;
exports.convertDate = convertDate;
exports.Style = exports.Color = exports.kSerializeData = exports.serverRegExp = exports.skinRegExp = exports.profileSkinsRegExp = exports.profileRegExp = exports.nameRegExp = exports.steveSkinHash = void 0;

var axios = require("axios");

var _WrapperError = require("./WrapperError");

function _wrapRegExp() { _wrapRegExp = function (re, groups) { return new BabelRegExp(re, undefined, groups); }; var _super = RegExp.prototype; var _groups = new WeakMap(); function BabelRegExp(re, flags, groups) { var _this = new RegExp(re, flags); _groups.set(_this, groups || _groups.get(re)); return _setPrototypeOf(_this, BabelRegExp.prototype); } _inherits(BabelRegExp, RegExp); BabelRegExp.prototype.exec = function (str) { var result = _super.exec.call(this, str); if (result) result.groups = buildGroups(result, this); return result; }; BabelRegExp.prototype[Symbol.replace] = function (str, substitution) { if (typeof substitution === "string") { var groups = _groups.get(this); return _super[Symbol.replace].call(this, str, substitution.replace(/\$<([^>]+)>/g, function (_, name) { return "$" + groups[name]; })); } else if (typeof substitution === "function") { var _this = this; return _super[Symbol.replace].call(this, str, function () { var args = arguments; if (typeof args[args.length - 1] !== "object") { args = [].slice.call(args); args.push(buildGroups(args, _this)); } return substitution.apply(this, args); }); } else { return _super[Symbol.replace].call(this, str, substitution); } }; function buildGroups(result, re) { var g = _groups.get(re); return Object.keys(g).reduce(function (groups, name) { groups[name] = result[g[name]]; return groups; }, Object.create(null)); } return _wrapRegExp.apply(this, arguments); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

const steveSkinHash = "12b92a9206470fe2";
exports.steveSkinHash = steveSkinHash;

const nameRegExp = /*#__PURE__*/_wrapRegExp(/^(?:([0-9A-Z_a-z]{1,16})|([0-9a-f]{8}\x2D?[0-9a-f]{4}\x2D?[0-5][0-9a-f]{3}\x2D?[089ab][0-9a-f]{3}\x2D?[0-9a-f]{12}))$/, {
  name: 1,
  uuid: 2
});

exports.nameRegExp = nameRegExp;
const profileRegExp = /(?:[^]+)?\/profile\/(?:([^]+)\.([\d]+)|([^]+))/;
exports.profileRegExp = profileRegExp;
const profileSkinsRegExp = /\/minecraft-skins\/profile\/([^]+)/;
exports.profileSkinsRegExp = profileSkinsRegExp;
const skinRegExp = /(?:[^]+)?\/skin\/([^]+)/;
exports.skinRegExp = skinRegExp;
const serverRegExp = /(?:[^]+)?\/server\/([^]+)/;
exports.serverRegExp = serverRegExp;
const kSerializeData = Symbol("serializeData");
/**
 * Minecraft HEX colors
 */

exports.kSerializeData = kSerializeData;
var Color;
exports.Color = Color;

(function (Color) {
  Color["BLACK"] = "000000";
  Color["DARK_BLUE"] = "0000AA";
  Color["DARK_GREEN"] = "00AA00";
  Color["DARK_AQUA"] = "00AAAA";
  Color["DARK_RED"] = "AA0000";
  Color["DARK_PURPLE"] = "AA00AA";
  Color["GOLD"] = "FFAA00";
  Color["GRAY"] = "AAAAAA";
  Color["DARK_GRAY"] = "AAAAAA";
  Color["BLUE"] = "5555FF";
  Color["GREEN"] = "55FF55";
  Color["AQUA"] = "55FFFF";
  Color["RED"] = "FF5555";
  Color["LIGHT_PURPLE"] = "FF55FF";
  Color["YELLOW"] = "FFFF55";
  Color["WHITE"] = "FFFFFF";
  Color["RESET"] = "AAAAAA";
})(Color || (exports.Color = Color = {}));
/**
 * Minecraft formatting css styles
 */


var Style;
exports.Style = Style;

(function (Style) {
  Style["BOLD"] = "font-weight: bold;";
  Style["UNDERLINED"] = "text-decoration: underline;";
  Style["STRIKETHROUGH"] = "text-decoration: line-through;";
  Style["ITALIC"] = "font-style: italic;";
})(Style || (exports.Style = Style = {}));

async function getUUID(endpoint, username) {
  var _isNickname$groups$uu, _isNickname$groups;

  const isNickname = username.match(nameRegExp);

  if (!isNickname) {
    throw new _WrapperError.WrapperError("INVALID_NICKNAME", username);
  } // @ts-ignore
  // eslint-disable-next-line no-return-await


  return (_isNickname$groups$uu = (_isNickname$groups = isNickname.groups) === null || _isNickname$groups === void 0 ? void 0 : _isNickname$groups.uuid) !== null && _isNickname$groups$uu !== void 0 ? _isNickname$groups$uu : await axios.get(`${endpoint}/mojang/v1/user/${username}`).then(({
    data: {
      uuid
    }
  }) => uuid).catch(error => {
    var _error$response;

    throw (error === null || error === void 0 ? void 0 : (_error$response = error.response) === null || _error$response === void 0 ? void 0 : _error$response.status) === 404 ? new _WrapperError.WrapperError("NOT_FOUND", username) : error;
  });
}

function escapeColorsClasses(elements) {
  return elements.map(element => {
    var _element$attribs;

    if (element.children && element.children.length !== 1) {
      return escapeColorsClasses(element.children);
    }

    if ((_element$attribs = element.attribs) !== null && _element$attribs !== void 0 && _element$attribs.class) {
      element.attribs.style = element.attribs.class.split(" ").map(style => {
        style = style.replace("mc-", "").replace("-", "_");

        switch (style) {
          case "bold":
          case "underlined":
          case "strikethrough":
          case "italic":
            return Style[style];

          default:
            return `color: #${Color[style.toUpperCase()]};`;
        }
      }).join("");
      delete element.attribs.class;
    }

    return element;
  }).flat(Infinity);
}

function escapeHtml(elements) {
  return elements.map(element => {
    if (element.type !== "text") {
      return escapeHtml(element.children);
    } // @ts-ignore


    return element.data;
  }).join("");
}

function parseDuration(duration) {
  const minute = 60;
  const hour = 60 * minute;
  const day = 24 * hour;
  const offset = [minute, hour, day];
  return duration.split(" ").reverse().reduce((acc, rawValue, index) => {
    const value = Number(rawValue.replace(/[^\d]+/g, ""));
    acc += value * offset[index];
    return acc;
  }, 0);
}

function applyPayload(context, payload) {
  Object.entries(payload).forEach(([key, value]) => {
    context[key] = value;
  });
}

function pickProperties(params, properties) {
  const copies = {};

  for (const property of properties) {
    copies[property] = params[property];
  }

  return copies;
}

function convertDate(fullDate) {
  const [date, time] = fullDate.split(", ");
  const ISODate = date.split(".").reverse().join("-");
  return new Date(`${ISODate}T${time}`).getTime();
}